# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_appflow.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_appflow.proto\x12\x17oak9.tython.aws.appflow\x1a\x13shared/shared.proto\"\x82\x01\n1ConnectorProfileDatadogConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cinstance_url\x18\x02 \x01(\t\"\x84\x01\n3ConnectorProfileDynatraceConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cinstance_url\x18\x02 \x01(\t\"\x85\x01\n4ConnectorProfileInforNexusConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cinstance_url\x18\x02 \x01(\t\"\x82\x01\n1ConnectorProfileMarketoConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cinstance_url\x18\x02 \x01(\t\"\xc1\x01\n2ConnectorProfileRedshiftConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x64\x61tabase_url\x18\x02 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x03 \x01(\t\x12\x15\n\rbucket_prefix\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\"\xa5\x01\n4ConnectorProfileSalesforceConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cinstance_url\x18\x02 \x01(\t\x12\x1e\n\x16is_sandbox_environment\x18\x03 \x01(\x08\"\x85\x01\n4ConnectorProfileServiceNowConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cinstance_url\x18\x02 \x01(\t\"\x80\x01\n/ConnectorProfileSlackConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cinstance_url\x18\x02 \x01(\t\"\x85\x02\n3ConnectorProfileSnowflakeConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\twarehouse\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x04 \x01(\t\x12\x15\n\rbucket_prefix\x18\x05 \x01(\t\x12!\n\x19private_link_service_name\x18\x06 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\"\x80\x01\n/ConnectorProfileVeevaConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cinstance_url\x18\x02 \x01(\t\"\x82\x01\n1ConnectorProfileZendeskConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cinstance_url\x18\x02 \x01(\t\"\xfa\x08\n*ConnectorProfileConnectorProfileProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12[\n\x07\x64\x61tadog\x18\x02 \x01(\x0b\x32J.oak9.tython.aws.appflow.ConnectorProfileDatadogConnectorProfileProperties\x12_\n\tdynatrace\x18\x03 \x01(\x0b\x32L.oak9.tython.aws.appflow.ConnectorProfileDynatraceConnectorProfileProperties\x12\x62\n\x0binfor_nexus\x18\x04 \x01(\x0b\x32M.oak9.tython.aws.appflow.ConnectorProfileInforNexusConnectorProfileProperties\x12[\n\x07marketo\x18\x05 \x01(\x0b\x32J.oak9.tython.aws.appflow.ConnectorProfileMarketoConnectorProfileProperties\x12]\n\x08redshift\x18\x06 \x01(\x0b\x32K.oak9.tython.aws.appflow.ConnectorProfileRedshiftConnectorProfileProperties\x12\x61\n\nsalesforce\x18\x07 \x01(\x0b\x32M.oak9.tython.aws.appflow.ConnectorProfileSalesforceConnectorProfileProperties\x12\x62\n\x0bservice_now\x18\x08 \x01(\x0b\x32M.oak9.tython.aws.appflow.ConnectorProfileServiceNowConnectorProfileProperties\x12W\n\x05slack\x18\t \x01(\x0b\x32H.oak9.tython.aws.appflow.ConnectorProfileSlackConnectorProfileProperties\x12_\n\tsnowflake\x18\n \x01(\x0b\x32L.oak9.tython.aws.appflow.ConnectorProfileSnowflakeConnectorProfileProperties\x12W\n\x05veeva\x18\x0b \x01(\x0b\x32H.oak9.tython.aws.appflow.ConnectorProfileVeevaConnectorProfileProperties\x12[\n\x07zendesk\x18\x0c \x01(\x0b\x32J.oak9.tython.aws.appflow.ConnectorProfileZendeskConnectorProfileProperties\"\x94\x01\n4ConnectorProfileAmplitudeConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\x12\x12\n\nsecret_key\x18\x03 \x01(\t\"\x97\x01\n2ConnectorProfileDatadogConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\x12\x17\n\x0f\x61pplication_key\x18\x03 \x01(\t\"\x82\x01\n4ConnectorProfileDynatraceConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tapi_token\x18\x02 \x01(\t\"\x89\x01\n%ConnectorProfileConnectorOAuthRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tauth_code\x18\x02 \x01(\t\x12\x14\n\x0credirect_uri\x18\x03 \x01(\t\"\xae\x02\n:ConnectorProfileGoogleAnalyticsConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x15\n\rclient_secret\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\t\x12\x15\n\rrefresh_token\x18\x05 \x01(\t\x12`\n\x18\x63onnector_o_auth_request\x18\x06 \x01(\x0b\x32>.oak9.tython.aws.appflow.ConnectorProfileConnectorOAuthRequest\"\xc4\x01\n5ConnectorProfileInforNexusConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\raccess_key_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x19\n\x11secret_access_key\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x61takey\x18\x05 \x01(\t\"\x8f\x02\n2ConnectorProfileMarketoConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x15\n\rclient_secret\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\t\x12`\n\x18\x63onnector_o_auth_request\x18\x05 \x01(\x0b\x32>.oak9.tython.aws.appflow.ConnectorProfileConnectorOAuthRequest\"\x92\x01\n3ConnectorProfileRedshiftConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\xff\x01\n5ConnectorProfileSalesforceConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\t\x12\x15\n\rrefresh_token\x18\x03 \x01(\t\x12`\n\x18\x63onnector_o_auth_request\x18\x04 \x01(\x0b\x32>.oak9.tython.aws.appflow.ConnectorProfileConnectorOAuthRequest\"\x94\x01\n5ConnectorProfileServiceNowConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\x7f\n3ConnectorProfileSingularConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\"\x8d\x02\n0ConnectorProfileSlackConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x15\n\rclient_secret\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\t\x12`\n\x18\x63onnector_o_auth_request\x18\x05 \x01(\x0b\x32>.oak9.tython.aws.appflow.ConnectorProfileConnectorOAuthRequest\"\x93\x01\n4ConnectorProfileSnowflakeConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\x88\x01\n5ConnectorProfileTrendmicroConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61pi_secret_key\x18\x02 \x01(\t\"\x8f\x01\n0ConnectorProfileVeevaConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\x8f\x02\n2ConnectorProfileZendeskConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x15\n\rclient_secret\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\t\x12`\n\x18\x63onnector_o_auth_request\x18\x05 \x01(\x0b\x32>.oak9.tython.aws.appflow.ConnectorProfileConnectorOAuthRequest\"\x9b\x0c\n+ConnectorProfileConnectorProfileCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\tamplitude\x18\x02 \x01(\x0b\x32M.oak9.tython.aws.appflow.ConnectorProfileAmplitudeConnectorProfileCredentials\x12\\\n\x07\x64\x61tadog\x18\x03 \x01(\x0b\x32K.oak9.tython.aws.appflow.ConnectorProfileDatadogConnectorProfileCredentials\x12`\n\tdynatrace\x18\x04 \x01(\x0b\x32M.oak9.tython.aws.appflow.ConnectorProfileDynatraceConnectorProfileCredentials\x12m\n\x10google_analytics\x18\x05 \x01(\x0b\x32S.oak9.tython.aws.appflow.ConnectorProfileGoogleAnalyticsConnectorProfileCredentials\x12\x63\n\x0binfor_nexus\x18\x06 \x01(\x0b\x32N.oak9.tython.aws.appflow.ConnectorProfileInforNexusConnectorProfileCredentials\x12\\\n\x07marketo\x18\x07 \x01(\x0b\x32K.oak9.tython.aws.appflow.ConnectorProfileMarketoConnectorProfileCredentials\x12^\n\x08redshift\x18\x08 \x01(\x0b\x32L.oak9.tython.aws.appflow.ConnectorProfileRedshiftConnectorProfileCredentials\x12\x62\n\nsalesforce\x18\t \x01(\x0b\x32N.oak9.tython.aws.appflow.ConnectorProfileSalesforceConnectorProfileCredentials\x12\x63\n\x0bservice_now\x18\n \x01(\x0b\x32N.oak9.tython.aws.appflow.ConnectorProfileServiceNowConnectorProfileCredentials\x12^\n\x08singular\x18\x0b \x01(\x0b\x32L.oak9.tython.aws.appflow.ConnectorProfileSingularConnectorProfileCredentials\x12X\n\x05slack\x18\x0c \x01(\x0b\x32I.oak9.tython.aws.appflow.ConnectorProfileSlackConnectorProfileCredentials\x12`\n\tsnowflake\x18\r \x01(\x0b\x32M.oak9.tython.aws.appflow.ConnectorProfileSnowflakeConnectorProfileCredentials\x12\x62\n\ntrendmicro\x18\x0e \x01(\x0b\x32N.oak9.tython.aws.appflow.ConnectorProfileTrendmicroConnectorProfileCredentials\x12X\n\x05veeva\x18\x0f \x01(\x0b\x32I.oak9.tython.aws.appflow.ConnectorProfileVeevaConnectorProfileCredentials\x12\\\n\x07zendesk\x18\x10 \x01(\x0b\x32K.oak9.tython.aws.appflow.ConnectorProfileZendeskConnectorProfileCredentials\"\xb9\x02\n&ConnectorProfileConnectorProfileConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12i\n\x1c\x63onnector_profile_properties\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.appflow.ConnectorProfileConnectorProfileProperties\x12k\n\x1d\x63onnector_profile_credentials\x18\x03 \x01(\x0b\x32\x44.oak9.tython.aws.appflow.ConnectorProfileConnectorProfileCredentials\"\x90\x02\n\x10\x43onnectorProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x63onnector_profile_name\x18\x02 \x01(\t\x12\x0f\n\x07kms_arn\x18\x03 \x01(\t\x12\x16\n\x0e\x63onnector_type\x18\x04 \x01(\t\x12\x17\n\x0f\x63onnection_mode\x18\x05 \x01(\t\x12\x61\n\x18\x63onnector_profile_config\x18\x06 \x01(\x0b\x32?.oak9.tython.aws.appflow.ConnectorProfileConnectorProfileConfig\"|\n\x07\x41ppFlow\x12\x44\n\x11\x63onnector_profile\x18\x01 \x03(\x0b\x32).oak9.tython.aws.appflow.ConnectorProfile\x12+\n\x04\x66low\x18\x02 \x03(\x0b\x32\x1d.oak9.tython.aws.appflow.Flow\"\xd9\x01\n\x1e\x46lowScheduledTriggerProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13schedule_expression\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x61ta_pull_mode\x18\x03 \x01(\t\x12\x1b\n\x13schedule_start_time\x18\x04 \x01(\x01\x12\x19\n\x11schedule_end_time\x18\x05 \x01(\x01\x12\x11\n\ttime_zone\x18\x06 \x01(\t\"\xb7\x01\n\x11\x46lowTriggerConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0ctrigger_type\x18\x02 \x01(\t\x12S\n\x12trigger_properties\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.appflow.FlowScheduledTriggerProperties\"h\n\x1d\x46lowAmplitudeSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"f\n\x1b\x46lowDatadogSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"h\n\x1d\x46lowDynatraceSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"n\n#FlowGoogleAnalyticsSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"i\n\x1e\x46lowInforNexusSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"f\n\x1b\x46lowMarketoSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"}\n\x16\x46lowS3SourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x62ucket_name\x18\x02 \x01(\t\x12\x15\n\rbucket_prefix\x18\x03 \x01(\t\"\xaf\x01\n\x1e\x46lowSalesforceSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\x12#\n\x1b\x65nable_dynamic_field_update\x18\x03 \x01(\x08\x12\x1f\n\x17include_deleted_records\x18\x04 \x01(\x08\"i\n\x1e\x46lowServiceNowSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"g\n\x1c\x46lowSingularSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"d\n\x19\x46lowSlackSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"i\n\x1e\x46lowTrendmicroSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"d\n\x19\x46lowVeevaSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"f\n\x1b\x46lowZendeskSourceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\"\xdd\x08\n\x1d\x46lowSourceConnectorProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\tamplitude\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.appflow.FlowAmplitudeSourceProperties\x12\x45\n\x07\x64\x61tadog\x18\x03 \x01(\x0b\x32\x34.oak9.tython.aws.appflow.FlowDatadogSourceProperties\x12I\n\tdynatrace\x18\x04 \x01(\x0b\x32\x36.oak9.tython.aws.appflow.FlowDynatraceSourceProperties\x12V\n\x10google_analytics\x18\x05 \x01(\x0b\x32<.oak9.tython.aws.appflow.FlowGoogleAnalyticsSourceProperties\x12L\n\x0binfor_nexus\x18\x06 \x01(\x0b\x32\x37.oak9.tython.aws.appflow.FlowInforNexusSourceProperties\x12\x45\n\x07marketo\x18\x07 \x01(\x0b\x32\x34.oak9.tython.aws.appflow.FlowMarketoSourceProperties\x12;\n\x02s3\x18\x08 \x01(\x0b\x32/.oak9.tython.aws.appflow.FlowS3SourceProperties\x12K\n\nsalesforce\x18\t \x01(\x0b\x32\x37.oak9.tython.aws.appflow.FlowSalesforceSourceProperties\x12L\n\x0bservice_now\x18\n \x01(\x0b\x32\x37.oak9.tython.aws.appflow.FlowServiceNowSourceProperties\x12G\n\x08singular\x18\x0b \x01(\x0b\x32\x35.oak9.tython.aws.appflow.FlowSingularSourceProperties\x12\x41\n\x05slack\x18\x0c \x01(\x0b\x32\x32.oak9.tython.aws.appflow.FlowSlackSourceProperties\x12K\n\ntrendmicro\x18\r \x01(\x0b\x32\x37.oak9.tython.aws.appflow.FlowTrendmicroSourceProperties\x12\x41\n\x05veeva\x18\x0e \x01(\x0b\x32\x32.oak9.tython.aws.appflow.FlowVeevaSourceProperties\x12\x45\n\x07zendesk\x18\x0f \x01(\x0b\x32\x34.oak9.tython.aws.appflow.FlowZendeskSourceProperties\"\xe4\x01\n\x14\x46lowSourceFlowConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63onnector_type\x18\x02 \x01(\t\x12\x1e\n\x16\x63onnector_profile_name\x18\x03 \x01(\t\x12[\n\x1bsource_connector_properties\x18\x04 \x01(\x0b\x32\x36.oak9.tython.aws.appflow.FlowSourceConnectorProperties\"\x9b\x01\n\x17\x46lowErrorHandlingConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x66\x61il_on_first_error\x18\x02 \x01(\x08\x12\x15\n\rbucket_prefix\x18\x03 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x04 \x01(\t\"\xf6\x01\n!FlowRedshiftDestinationProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\x12 \n\x18intermediate_bucket_name\x18\x03 \x01(\t\x12\x15\n\rbucket_prefix\x18\x04 \x01(\t\x12O\n\x15\x65rror_handling_config\x18\x05 \x01(\x0b\x32\x30.oak9.tython.aws.appflow.FlowErrorHandlingConfig\"w\n\x10\x46lowPrefixConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bprefix_type\x18\x02 \x01(\t\x12\x15\n\rprefix_format\x18\x03 \x01(\t\"j\n\x15\x46lowAggregationConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61ggregation_type\x18\x02 \x01(\t\"\xf4\x01\n\x18\x46lowS3OutputFormatConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tfile_type\x18\x02 \x01(\t\x12@\n\rprefix_config\x18\x03 \x01(\x0b\x32).oak9.tython.aws.appflow.FlowPrefixConfig\x12J\n\x12\x61ggregation_config\x18\x04 \x01(\x0b\x32..oak9.tython.aws.appflow.FlowAggregationConfig\"\xd6\x01\n\x1b\x46lowS3DestinationProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x62ucket_name\x18\x02 \x01(\t\x12\x15\n\rbucket_prefix\x18\x03 \x01(\t\x12R\n\x17s3_output_format_config\x18\x04 \x01(\x0b\x32\x31.oak9.tython.aws.appflow.FlowS3OutputFormatConfig\"\xbf\x01\n#FlowSalesforceDestinationProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\x12O\n\x15\x65rror_handling_config\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.appflow.FlowErrorHandlingConfig\"\xf7\x01\n\"FlowSnowflakeDestinationProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\x12 \n\x18intermediate_bucket_name\x18\x03 \x01(\t\x12\x15\n\rbucket_prefix\x18\x04 \x01(\t\x12O\n\x15\x65rror_handling_config\x18\x05 \x01(\x0b\x32\x30.oak9.tython.aws.appflow.FlowErrorHandlingConfig\"\xc0\x01\n$FlowEventBridgeDestinationProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06object\x18\x02 \x01(\t\x12O\n\x15\x65rror_handling_config\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.appflow.FlowErrorHandlingConfig\"\xe4\x03\n\"FlowDestinationConnectorProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x08redshift\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.appflow.FlowRedshiftDestinationProperties\x12@\n\x02s3\x18\x03 \x01(\x0b\x32\x34.oak9.tython.aws.appflow.FlowS3DestinationProperties\x12P\n\nsalesforce\x18\x04 \x01(\x0b\x32<.oak9.tython.aws.appflow.FlowSalesforceDestinationProperties\x12N\n\tsnowflake\x18\x05 \x01(\x0b\x32;.oak9.tython.aws.appflow.FlowSnowflakeDestinationProperties\x12S\n\x0c\x65vent_bridge\x18\x06 \x01(\x0b\x32=.oak9.tython.aws.appflow.FlowEventBridgeDestinationProperties\"\xf3\x01\n\x19\x46lowDestinationFlowConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63onnector_type\x18\x02 \x01(\t\x12\x1e\n\x16\x63onnector_profile_name\x18\x03 \x01(\t\x12\x65\n destination_connector_properties\x18\x04 \x01(\x0b\x32;.oak9.tython.aws.appflow.FlowDestinationConnectorProperties\"\xd1\x02\n\x15\x46lowConnectorOperator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tamplitude\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x61tadog\x18\x03 \x01(\t\x12\x11\n\tdynatrace\x18\x04 \x01(\t\x12\x18\n\x10google_analytics\x18\x05 \x01(\t\x12\x13\n\x0binfor_nexus\x18\x06 \x01(\t\x12\x0f\n\x07marketo\x18\x07 \x01(\t\x12\n\n\x02s3\x18\x08 \x01(\t\x12\x12\n\nsalesforce\x18\t \x01(\t\x12\x13\n\x0bservice_now\x18\n \x01(\t\x12\x10\n\x08singular\x18\x0b \x01(\t\x12\r\n\x05slack\x18\x0c \x01(\t\x12\x12\n\ntrendmicro\x18\r \x01(\t\x12\r\n\x05veeva\x18\x0e \x01(\t\x12\x0f\n\x07zendesk\x18\x0f \x01(\t\"o\n\x18\x46lowTaskPropertiesObject\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xa0\x02\n\x08\x46lowTask\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rsource_fields\x18\x02 \x03(\t\x12J\n\x12\x63onnector_operator\x18\x03 \x01(\x0b\x32..oak9.tython.aws.appflow.FlowConnectorOperator\x12\x19\n\x11\x64\x65stination_field\x18\x04 \x01(\t\x12\x11\n\ttask_type\x18\x05 \x01(\t\x12J\n\x0ftask_properties\x18\x06 \x03(\x0b\x32\x31.oak9.tython.aws.appflow.FlowTaskPropertiesObject\"\xf7\x03\n\x04\x46low\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tflow_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07kms_arn\x18\x04 \x01(\t\x12\x42\n\x0etrigger_config\x18\x05 \x01(\x0b\x32*.oak9.tython.aws.appflow.FlowTriggerConfig\x12I\n\x12source_flow_config\x18\x06 \x01(\x0b\x32-.oak9.tython.aws.appflow.FlowSourceFlowConfig\x12X\n\x1c\x64\x65stination_flow_config_list\x18\x07 \x03(\x0b\x32\x32.oak9.tython.aws.appflow.FlowDestinationFlowConfig\x12\x30\n\x05tasks\x18\x08 \x03(\x0b\x32!.oak9.tython.aws.appflow.FlowTask\x12\x35\n\x04tags\x18\t \x03(\x0b\x32\'.oak9.tython.aws.appflow.Flow.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_appflow_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FLOW_TAGSENTRY._options = None
  _FLOW_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTORPROFILEDATADOGCONNECTORPROFILEPROPERTIES._serialized_start=72
  _CONNECTORPROFILEDATADOGCONNECTORPROFILEPROPERTIES._serialized_end=202
  _CONNECTORPROFILEDYNATRACECONNECTORPROFILEPROPERTIES._serialized_start=205
  _CONNECTORPROFILEDYNATRACECONNECTORPROFILEPROPERTIES._serialized_end=337
  _CONNECTORPROFILEINFORNEXUSCONNECTORPROFILEPROPERTIES._serialized_start=340
  _CONNECTORPROFILEINFORNEXUSCONNECTORPROFILEPROPERTIES._serialized_end=473
  _CONNECTORPROFILEMARKETOCONNECTORPROFILEPROPERTIES._serialized_start=476
  _CONNECTORPROFILEMARKETOCONNECTORPROFILEPROPERTIES._serialized_end=606
  _CONNECTORPROFILEREDSHIFTCONNECTORPROFILEPROPERTIES._serialized_start=609
  _CONNECTORPROFILEREDSHIFTCONNECTORPROFILEPROPERTIES._serialized_end=802
  _CONNECTORPROFILESALESFORCECONNECTORPROFILEPROPERTIES._serialized_start=805
  _CONNECTORPROFILESALESFORCECONNECTORPROFILEPROPERTIES._serialized_end=970
  _CONNECTORPROFILESERVICENOWCONNECTORPROFILEPROPERTIES._serialized_start=973
  _CONNECTORPROFILESERVICENOWCONNECTORPROFILEPROPERTIES._serialized_end=1106
  _CONNECTORPROFILESLACKCONNECTORPROFILEPROPERTIES._serialized_start=1109
  _CONNECTORPROFILESLACKCONNECTORPROFILEPROPERTIES._serialized_end=1237
  _CONNECTORPROFILESNOWFLAKECONNECTORPROFILEPROPERTIES._serialized_start=1240
  _CONNECTORPROFILESNOWFLAKECONNECTORPROFILEPROPERTIES._serialized_end=1501
  _CONNECTORPROFILEVEEVACONNECTORPROFILEPROPERTIES._serialized_start=1504
  _CONNECTORPROFILEVEEVACONNECTORPROFILEPROPERTIES._serialized_end=1632
  _CONNECTORPROFILEZENDESKCONNECTORPROFILEPROPERTIES._serialized_start=1635
  _CONNECTORPROFILEZENDESKCONNECTORPROFILEPROPERTIES._serialized_end=1765
  _CONNECTORPROFILECONNECTORPROFILEPROPERTIES._serialized_start=1768
  _CONNECTORPROFILECONNECTORPROFILEPROPERTIES._serialized_end=2914
  _CONNECTORPROFILEAMPLITUDECONNECTORPROFILECREDENTIALS._serialized_start=2917
  _CONNECTORPROFILEAMPLITUDECONNECTORPROFILECREDENTIALS._serialized_end=3065
  _CONNECTORPROFILEDATADOGCONNECTORPROFILECREDENTIALS._serialized_start=3068
  _CONNECTORPROFILEDATADOGCONNECTORPROFILECREDENTIALS._serialized_end=3219
  _CONNECTORPROFILEDYNATRACECONNECTORPROFILECREDENTIALS._serialized_start=3222
  _CONNECTORPROFILEDYNATRACECONNECTORPROFILECREDENTIALS._serialized_end=3352
  _CONNECTORPROFILECONNECTOROAUTHREQUEST._serialized_start=3355
  _CONNECTORPROFILECONNECTOROAUTHREQUEST._serialized_end=3492
  _CONNECTORPROFILEGOOGLEANALYTICSCONNECTORPROFILECREDENTIALS._serialized_start=3495
  _CONNECTORPROFILEGOOGLEANALYTICSCONNECTORPROFILECREDENTIALS._serialized_end=3797
  _CONNECTORPROFILEINFORNEXUSCONNECTORPROFILECREDENTIALS._serialized_start=3800
  _CONNECTORPROFILEINFORNEXUSCONNECTORPROFILECREDENTIALS._serialized_end=3996
  _CONNECTORPROFILEMARKETOCONNECTORPROFILECREDENTIALS._serialized_start=3999
  _CONNECTORPROFILEMARKETOCONNECTORPROFILECREDENTIALS._serialized_end=4270
  _CONNECTORPROFILEREDSHIFTCONNECTORPROFILECREDENTIALS._serialized_start=4273
  _CONNECTORPROFILEREDSHIFTCONNECTORPROFILECREDENTIALS._serialized_end=4419
  _CONNECTORPROFILESALESFORCECONNECTORPROFILECREDENTIALS._serialized_start=4422
  _CONNECTORPROFILESALESFORCECONNECTORPROFILECREDENTIALS._serialized_end=4677
  _CONNECTORPROFILESERVICENOWCONNECTORPROFILECREDENTIALS._serialized_start=4680
  _CONNECTORPROFILESERVICENOWCONNECTORPROFILECREDENTIALS._serialized_end=4828
  _CONNECTORPROFILESINGULARCONNECTORPROFILECREDENTIALS._serialized_start=4830
  _CONNECTORPROFILESINGULARCONNECTORPROFILECREDENTIALS._serialized_end=4957
  _CONNECTORPROFILESLACKCONNECTORPROFILECREDENTIALS._serialized_start=4960
  _CONNECTORPROFILESLACKCONNECTORPROFILECREDENTIALS._serialized_end=5229
  _CONNECTORPROFILESNOWFLAKECONNECTORPROFILECREDENTIALS._serialized_start=5232
  _CONNECTORPROFILESNOWFLAKECONNECTORPROFILECREDENTIALS._serialized_end=5379
  _CONNECTORPROFILETRENDMICROCONNECTORPROFILECREDENTIALS._serialized_start=5382
  _CONNECTORPROFILETRENDMICROCONNECTORPROFILECREDENTIALS._serialized_end=5518
  _CONNECTORPROFILEVEEVACONNECTORPROFILECREDENTIALS._serialized_start=5521
  _CONNECTORPROFILEVEEVACONNECTORPROFILECREDENTIALS._serialized_end=5664
  _CONNECTORPROFILEZENDESKCONNECTORPROFILECREDENTIALS._serialized_start=5667
  _CONNECTORPROFILEZENDESKCONNECTORPROFILECREDENTIALS._serialized_end=5938
  _CONNECTORPROFILECONNECTORPROFILECREDENTIALS._serialized_start=5941
  _CONNECTORPROFILECONNECTORPROFILECREDENTIALS._serialized_end=7504
  _CONNECTORPROFILECONNECTORPROFILECONFIG._serialized_start=7507
  _CONNECTORPROFILECONNECTORPROFILECONFIG._serialized_end=7820
  _CONNECTORPROFILE._serialized_start=7823
  _CONNECTORPROFILE._serialized_end=8095
  _APPFLOW._serialized_start=8097
  _APPFLOW._serialized_end=8221
  _FLOWSCHEDULEDTRIGGERPROPERTIES._serialized_start=8224
  _FLOWSCHEDULEDTRIGGERPROPERTIES._serialized_end=8441
  _FLOWTRIGGERCONFIG._serialized_start=8444
  _FLOWTRIGGERCONFIG._serialized_end=8627
  _FLOWAMPLITUDESOURCEPROPERTIES._serialized_start=8629
  _FLOWAMPLITUDESOURCEPROPERTIES._serialized_end=8733
  _FLOWDATADOGSOURCEPROPERTIES._serialized_start=8735
  _FLOWDATADOGSOURCEPROPERTIES._serialized_end=8837
  _FLOWDYNATRACESOURCEPROPERTIES._serialized_start=8839
  _FLOWDYNATRACESOURCEPROPERTIES._serialized_end=8943
  _FLOWGOOGLEANALYTICSSOURCEPROPERTIES._serialized_start=8945
  _FLOWGOOGLEANALYTICSSOURCEPROPERTIES._serialized_end=9055
  _FLOWINFORNEXUSSOURCEPROPERTIES._serialized_start=9057
  _FLOWINFORNEXUSSOURCEPROPERTIES._serialized_end=9162
  _FLOWMARKETOSOURCEPROPERTIES._serialized_start=9164
  _FLOWMARKETOSOURCEPROPERTIES._serialized_end=9266
  _FLOWS3SOURCEPROPERTIES._serialized_start=9268
  _FLOWS3SOURCEPROPERTIES._serialized_end=9393
  _FLOWSALESFORCESOURCEPROPERTIES._serialized_start=9396
  _FLOWSALESFORCESOURCEPROPERTIES._serialized_end=9571
  _FLOWSERVICENOWSOURCEPROPERTIES._serialized_start=9573
  _FLOWSERVICENOWSOURCEPROPERTIES._serialized_end=9678
  _FLOWSINGULARSOURCEPROPERTIES._serialized_start=9680
  _FLOWSINGULARSOURCEPROPERTIES._serialized_end=9783
  _FLOWSLACKSOURCEPROPERTIES._serialized_start=9785
  _FLOWSLACKSOURCEPROPERTIES._serialized_end=9885
  _FLOWTRENDMICROSOURCEPROPERTIES._serialized_start=9887
  _FLOWTRENDMICROSOURCEPROPERTIES._serialized_end=9992
  _FLOWVEEVASOURCEPROPERTIES._serialized_start=9994
  _FLOWVEEVASOURCEPROPERTIES._serialized_end=10094
  _FLOWZENDESKSOURCEPROPERTIES._serialized_start=10096
  _FLOWZENDESKSOURCEPROPERTIES._serialized_end=10198
  _FLOWSOURCECONNECTORPROPERTIES._serialized_start=10201
  _FLOWSOURCECONNECTORPROPERTIES._serialized_end=11318
  _FLOWSOURCEFLOWCONFIG._serialized_start=11321
  _FLOWSOURCEFLOWCONFIG._serialized_end=11549
  _FLOWERRORHANDLINGCONFIG._serialized_start=11552
  _FLOWERRORHANDLINGCONFIG._serialized_end=11707
  _FLOWREDSHIFTDESTINATIONPROPERTIES._serialized_start=11710
  _FLOWREDSHIFTDESTINATIONPROPERTIES._serialized_end=11956
  _FLOWPREFIXCONFIG._serialized_start=11958
  _FLOWPREFIXCONFIG._serialized_end=12077
  _FLOWAGGREGATIONCONFIG._serialized_start=12079
  _FLOWAGGREGATIONCONFIG._serialized_end=12185
  _FLOWS3OUTPUTFORMATCONFIG._serialized_start=12188
  _FLOWS3OUTPUTFORMATCONFIG._serialized_end=12432
  _FLOWS3DESTINATIONPROPERTIES._serialized_start=12435
  _FLOWS3DESTINATIONPROPERTIES._serialized_end=12649
  _FLOWSALESFORCEDESTINATIONPROPERTIES._serialized_start=12652
  _FLOWSALESFORCEDESTINATIONPROPERTIES._serialized_end=12843
  _FLOWSNOWFLAKEDESTINATIONPROPERTIES._serialized_start=12846
  _FLOWSNOWFLAKEDESTINATIONPROPERTIES._serialized_end=13093
  _FLOWEVENTBRIDGEDESTINATIONPROPERTIES._serialized_start=13096
  _FLOWEVENTBRIDGEDESTINATIONPROPERTIES._serialized_end=13288
  _FLOWDESTINATIONCONNECTORPROPERTIES._serialized_start=13291
  _FLOWDESTINATIONCONNECTORPROPERTIES._serialized_end=13775
  _FLOWDESTINATIONFLOWCONFIG._serialized_start=13778
  _FLOWDESTINATIONFLOWCONFIG._serialized_end=14021
  _FLOWCONNECTOROPERATOR._serialized_start=14024
  _FLOWCONNECTOROPERATOR._serialized_end=14361
  _FLOWTASKPROPERTIESOBJECT._serialized_start=14363
  _FLOWTASKPROPERTIESOBJECT._serialized_end=14474
  _FLOWTASK._serialized_start=14477
  _FLOWTASK._serialized_end=14765
  _FLOW._serialized_start=14768
  _FLOW._serialized_end=15271
  _FLOW_TAGSENTRY._serialized_start=15228
  _FLOW_TAGSENTRY._serialized_end=15271
# @@protoc_insertion_point(module_scope)
